/**
 * @module botframework-connector
 */
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { AppCredentials } from './appCredentials';
import { AuthenticatorResult } from './authenticatorResult';
/**
 * MicrosoftAppCredentials auth implementation
 */
export declare class MicrosoftAppCredentials extends AppCredentials {
    appPassword: string;
    /**
     * An empty set of credentials.
     */
    static readonly Empty: MicrosoftAppCredentials;
    private credentials;
    /**
     * Initializes a new instance of the [MicrosoftAppCredentials](xref:botframework-connector.MicrosoftAppCredentials) class.
     *
     * @param {string} appId The Microsoft app ID.
     * @param {string} appPassword The Microsoft app password.
     * @param {string} channelAuthTenant Optional. The oauth token tenant.
     * @param {string} oAuthScope Optional. The scope for the token.
     */
    constructor(appId: string, appPassword: string, channelAuthTenant?: string, oAuthScope?: string);
    /**
     * @inheritdoc
     */
    getToken(forceRefresh?: boolean): Promise<string>;
    /**
     * @inheritdoc
     */
    protected refreshToken(): Promise<AuthenticatorResult>;
}
//# sourceMappingURL=microsoftAppCredentials.d.ts.map
