/**
 * @module botframework-connector
 */
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import type { AccessToken } from '@azure/identity';
import type { IJwtTokenProviderFactory } from './jwtTokenProviderFactory';
/**
 * Abstraction to acquire tokens from a Managed Service Identity.
 */
export declare class ManagedIdentityAuthenticator {
    private readonly tokenProvider;
    private readonly resource;
    /**
     * Initializes a new instance of the ManagedIdentityAuthenticator class.
     *
     * @param appId Client id for the managed identity to be used for acquiring tokens.
     * @param resource Resource for which to acquire the token.
     * @param tokenProviderFactory The JWT token provider factory to use.
     */
    constructor(appId: string, resource: string, tokenProviderFactory: IJwtTokenProviderFactory);
    /**
     * Acquires the security token.
     *
     * @returns {Promise<AccessToken>} A promise with the `AccessToken` provided by the [IJwtTokenProviderFactory](xref:botframework-connector.IJwtTokenProviderFactory) class.
     */
    getToken(): Promise<AccessToken>;
}
//# sourceMappingURL=managedIdentityAuthenticator.d.ts.map